#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-HotIIafN075J7loKfr5reM
key:                  monad-dijkstra-0.1.1.5-HotIIafN075J7loKfr5reM
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  8e2cd932f805cce61e3bd74c399367f7
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-HotIIafN075J7loKfr5reM
depends:
    base-4.18.2.1 containers-0.6.7 free-5.2-AR7GiDYG5Zn11znBIXJLbO
    mtl-2.3.1 psqueues-0.2.8.2-ARjgCfqJV3yLZCIUHQbw2w
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

